==> ejc-proequipmentp-impl-3.0.0-20220629.083632-148-sources.jar: com/ejianc/business/asset/bean/AssetAllotInDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 固定资产调入明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_equipment_asset_allot_in_detail")
public class AssetAllotInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="allocat_id")
    private Long allocatId; // 主表id
    @TableField(value="assets_id")
    private Long assetsId; // 固定资产id
    @TableField(value="assets_name")
    private String assetsName; // 固定资产名称
    @TableField(value="assets_code")
    private String assetsCode; // 固定资产编码
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="finance_asset_id")
    private String financeAssetId; // 财务资产id
    @TableField(value="finance_asset_code")
    private String financeAssetCode; // 财务资产编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="allocat_tax_rate")
    private BigDecimal allocatTaxRate; // 调拨税率
    @TableField(value="allocat_mny")
    private BigDecimal allocatMny; // 调拨金额
    @TableField(value="allocat_tax_mny")
    private BigDecimal allocatTaxMny; // 调拨金额（有税）
    @TableField(value="allocat_tax")
    private BigDecimal allocatTax; // 调拨税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="allot_diff_mny")
    private BigDecimal allotDiffMny; // 调拨差额(无税)
    @TableField(value="allot_diff_tax_mny")
    private BigDecimal allotDiffTaxMny; // 调拨差额
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_price_tax")
    private BigDecimal originalValuePriceTax; // 原值单价(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)

    
    

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }
    public Long getAssetsId() {
        return assetsId;
    }

    public void setAssetsId(Long assetsId) {
        this.assetsId = assetsId;
    }
    public String getAssetsName() {
        return assetsName;
    }

    public void setAssetsName(String assetsName) {
        this.assetsName = assetsName;
    }
    public String getAssetsCode() {
        return assetsCode;
    }

    public void setAssetsCode(String assetsCode) {
        this.assetsCode = assetsCode;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getFinanceAssetId() {
        return financeAssetId;
    }

    public void setFinanceAssetId(String financeAssetId) {
        this.financeAssetId = financeAssetId;
    }
    public String getFinanceAssetCode() {
        return financeAssetCode;
    }

    public void setFinanceAssetCode(String financeAssetCode) {
        this.financeAssetCode = financeAssetCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }
    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getAllotDiffMny() {
        return allotDiffMny;
    }

    public void setAllotDiffMny(BigDecimal allotDiffMny) {
        this.allotDiffMny = allotDiffMny;
    }
    public BigDecimal getAllotDiffTaxMny() {
        return allotDiffTaxMny;
    }

    public void setAllotDiffTaxMny(BigDecimal allotDiffTaxMny) {
        this.allotDiffTaxMny = allotDiffTaxMny;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }
    public BigDecimal getOriginalValuePriceTax() {
        return originalValuePriceTax;
    }

    public void setOriginalValuePriceTax(BigDecimal originalValuePriceTax) {
        this.originalValuePriceTax = originalValuePriceTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }

}

==> ejc-proequipmentp-impl-3.0.0-20220720.020208-194-sources.jar: com/ejianc/business/asset/bean/AssetAllotInDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 固定资产调入明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_asset_allot_in_detail")
public class AssetAllotInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="allocat_id")
    private Long allocatId; // 主表id
    @TableField(value="assets_id")
    private Long assetsId; // 固定资产id
    @TableField(value="assets_name")
    private String assetsName; // 固定资产名称
    @TableField(value="assets_code")
    private String assetsCode; // 固定资产编码
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="finance_asset_id")
    private String financeAssetId; // 财务资产id
    @TableField(value="finance_asset_code")
    private String financeAssetCode; // 财务资产编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="allocat_tax_rate")
    private BigDecimal allocatTaxRate; // 调拨税率
    @TableField(value="allocat_mny")
    private BigDecimal allocatMny; // 调拨金额
    @TableField(value="allocat_tax_mny")
    private BigDecimal allocatTaxMny; // 调拨金额（有税）
    @TableField(value="allocat_tax")
    private BigDecimal allocatTax; // 调拨税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="allot_diff_mny")
    private BigDecimal allotDiffMny; // 调拨差额(无税)
    @TableField(value="allot_diff_tax_mny")
    private BigDecimal allotDiffTaxMny; // 调拨差额
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_price_tax")
    private BigDecimal originalValuePriceTax; // 原值单价(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)

    
    

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }
    public Long getAssetsId() {
        return assetsId;
    }

    public void setAssetsId(Long assetsId) {
        this.assetsId = assetsId;
    }
    public String getAssetsName() {
        return assetsName;
    }

    public void setAssetsName(String assetsName) {
        this.assetsName = assetsName;
    }
    public String getAssetsCode() {
        return assetsCode;
    }

    public void setAssetsCode(String assetsCode) {
        this.assetsCode = assetsCode;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getFinanceAssetId() {
        return financeAssetId;
    }

    public void setFinanceAssetId(String financeAssetId) {
        this.financeAssetId = financeAssetId;
    }
    public String getFinanceAssetCode() {
        return financeAssetCode;
    }

    public void setFinanceAssetCode(String financeAssetCode) {
        this.financeAssetCode = financeAssetCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }
    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getAllotDiffMny() {
        return allotDiffMny;
    }

    public void setAllotDiffMny(BigDecimal allotDiffMny) {
        this.allotDiffMny = allotDiffMny;
    }
    public BigDecimal getAllotDiffTaxMny() {
        return allotDiffTaxMny;
    }

    public void setAllotDiffTaxMny(BigDecimal allotDiffTaxMny) {
        this.allotDiffTaxMny = allotDiffTaxMny;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }
    public BigDecimal getOriginalValuePriceTax() {
        return originalValuePriceTax;
    }

    public void setOriginalValuePriceTax(BigDecimal originalValuePriceTax) {
        this.originalValuePriceTax = originalValuePriceTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }

}
